@@ -258,12 +258,12 @@ get_acs <- function(geography, variables = NULL, table = NULL, cache_table = FAL
   # are requested - take care of this under the hood by having the function
   # call itself for "B" variables, "S" variabls and "DP" variables then combining the results
 
-  if (length(unique(substr(variables, 1, 1))) > 1) {
+  if (length(unique(substr(variables, 1, 1))) > 1 && !all(unique(substr(variables, 1, 1)) %in% c("B", "C"))) {
 
-    message('Fetching data by table type ("B", "S", "DP") and combining the result.')
+    message('Fetching data by table type ("B/C", "S", "DP") and combining the result.')
 
     # split variables by type into list, discard empty list elements
-    vars_by_type <- map(c("^B", "^S", "^D"), ~ str_subset(variables, .x)) %>%
+    vars_by_type <- map(c("^B|^C", "^S", "^D"), ~ str_subset(variables, .x)) %>%
       purrr::compact()
 
     if (geometry) {
