@@ -12,7 +12,7 @@
 #'                  combinations of these breakdowns.
 #' @param breakdown_labels Whether or not to label breakdown elements returned when
 #'                         \code{product = "characteristics"}. Defaults to FALSE.
-#' @param year The data year (defaults to 2017)
+#' @param year The data year (defaults to 2018)
 #' @param state The state for which you are requesting data. State
 #'              names, postal codes, and FIPS codes are accepted.
 #'              Defaults to NULL.
@@ -23,7 +23,7 @@
 #'                    of 2010. The returned column is either "DATE", representing a particular estimate date, or "PERIOD",
 #'                    representing a time period (e.g. births between 2016 and 2017), and contains integers representing
 #'                    those values.  Integer to date or period mapping is available at
-#'                    \url{https://www.census.gov/data/developers/data-sets/popest-popproj/popest/popest-vars/2017.html}.
+#'                    \url{https://www.census.gov/data/developers/data-sets/popest-popproj/popest/popest-vars/2018.html}.
 #' @param output One of "tidy" (the default) in which each row represents an
 #'               enumeration unit-variable combination, or "wide" in which each
 #'               row represents an enumeration unit and the variables are in the
@@ -38,17 +38,24 @@
 #' @param key Your Census API key.
 #'            Obtain one at \url{http://api.census.gov/data/key_signup.html}.  Can be stored
 #'            in your .Renviron with \code{census_api_key("YOUR KEY", install = TRUE)}
+#' @param show_call if TRUE, display call made to Census API. This can be very useful
+#'                  in debugging and determining if error messages returned are
+#'                  due to tidycensus or the Census API. Copy to the API call into
+#'                  a browser and see what is returned by the API directly. Defaults to FALSE.
 #' @param ... other keyword arguments
 #'
 #' @return A tibble, or sf tibble, of population estimates data
 #' @export
 get_estimates <- function(geography, product = NULL, variables = NULL,
                           breakdown = NULL, breakdown_labels = FALSE,
-                          year = 2017, state = NULL, county = NULL,
+                          year = 2018, state = NULL, county = NULL,
                           time_series = FALSE,
                           output = "tidy", geometry = FALSE, keep_geo_vars = FALSE,
-                          shift_geo = FALSE, key = NULL, ...) {
+                          shift_geo = FALSE, key = NULL, show_call = FALSE, ...) {
 
+  if (year < 2015) {
+    stop("The Population Estimates API is not available in tidycensus for years prior to 2015. Consider using `time_series = TRUE` or the censusapi package for earlier estimates.")
+  }
 
 
   if (Sys.getenv('CENSUS_API_KEY') != '') {
@@ -61,6 +68,73 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
 
   }
 
+  if (geography == "cbsa") geography <- "metropolitan statistical area/micropolitan statistical area"
+
+  insist_get_estimates <- purrr::insistently(get_estimates)
+
+  # Allow for characteristics products to be pulled for the entire US by county
+  # Come back to this later
+  if (!is.null(product)) {
+
+    if (is.null(state) && geography == "county" && product == "characteristics") {
+
+      message("Fetching characteristics data by state and combining the result.")
+
+      state <- unique(fips_codes$state_code)[1:51]
+      # mc <- match.call(expand.dots = TRUE)
+      if (geometry) {
+        result <- map(state,~{
+          suppressMessages(
+            insist_get_estimates(geography = geography,
+                                 product = product,
+                                 variables = variables,
+                                 breakdown = breakdown,
+                                 breakdown_labels = breakdown_labels,
+                                 year = year,
+                                 state = .x,
+                                 county = county,
+                                 time_series = time_series,
+                                 output = output,
+                                 geometry = geometry,
+                                 keep_geo_vars = keep_geo_vars,
+                                 shift_geo = shift_geo,
+                                 key = key,
+                                 show_call = show_call))
+        }) %>%
+          reduce(rbind)
+        geoms <- unique(st_geometry_type(result))
+        if (length(geoms) > 1) {
+          result <- st_cast(result, "MULTIPOLYGON")
+        }
+        result <- result %>%
+          as_tibble() %>%
+          st_as_sf()
+      } else {
+        result <- map_df(state, ~{
+          suppressMessages(
+            insist_get_estimates(geography = geography,
+                                 product = product,
+                                 variables = variables,
+                                 breakdown = breakdown,
+                                 breakdown_labels = breakdown_labels,
+                                 year = year,
+                                 state = .x,
+                                 county = county,
+                                 time_series = time_series,
+                                 output = output,
+                                 geometry = geometry,
+                                 keep_geo_vars = keep_geo_vars,
+                                 shift_geo = shift_geo,
+                                 key = key,
+                                 show_call = show_call))
+        })
+      }
+      return(result)
+
+    }
+
+  }
+
   if (!is.null(product) && product == "characteristics") {
     product <- "charagegroups"
   }
@@ -93,7 +167,7 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
       dat <- map_dfc(variables, function(eachvar) {
         load_data_estimates(geography = geography, product = NULL, variables = eachvar,
                             year = year, state = state, county = county,
-                            time_series = time_series, key = key)
+                            time_series = time_series, key = key, show_call = show_call)
       })
 
       # Remove any extra GEOID or GEONAME columns
@@ -104,20 +178,32 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
                                  variables = variables,
                                  year = year, state = state,
                                  time_series = time_series,
-                                 county = county, key = key)
+                                 county = county, key = key, show_call = show_call)
     }
   } else {
     dat <- load_data_estimates(geography = geography, product = product,
                                variables = variables,
                                year = year, state = state,
                                time_series = time_series,
-                               county = county, key = key)
+                               county = county, key = key, show_call = show_call)
   }
 
   if (!is.null(product) && product == "charagegroups") {
     output <- "wide"
   }
 
+  if ("PERIOD_CODE" %in% names(dat)) {
+    dat <- rename(dat, PERIOD = PERIOD_CODE)
+  }
+
+  if ("DATE_CODE" %in% names(dat)) {
+    dat <- rename(dat, DATE = DATE_CODE)
+  }
+
+  if ("DATE_" %in% names(dat)) {
+    dat <- rename(dat, DATE = DATE_)
+  }
+
   if (output == "tidy") {
 
     if (time_series) {
